summaryrefslogtreecommitdiff
path: root/usr.bin/ar/ar.c
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>2000-11-20 14:03:32 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>2000-11-20 14:03:32 +0000
commit2396970fc648109a84b955752bb59e513d688845 (patch)
treeb4a882b052cd8cef9145bc611bfd3ef9d57f92d2 /usr.bin/ar/ar.c
parent2bc7664f82176487bdeb1ae7086aae428d9fa69e (diff)
repairs; mpech@prosoft.org.lv
Diffstat (limited to 'usr.bin/ar/ar.c')
-rw-r--r--usr.bin/ar/ar.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/usr.bin/ar/ar.c b/usr.bin/ar/ar.c
index 0b289e962f3..673d759fff3 100644
--- a/usr.bin/ar/ar.c
+++ b/usr.bin/ar/ar.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ar.c,v 1.5 1999/12/15 05:33:23 deraadt Exp $ */
+/* $OpenBSD: ar.c,v 1.6 2000/11/20 14:03:30 deraadt Exp $ */
/* $NetBSD: ar.c,v 1.5 1995/03/26 03:27:44 glass Exp $ */
/*-
@@ -47,7 +47,7 @@ static char copyright[] =
#if 0
static char sccsid[] = "@(#)ar.c 8.3 (Berkeley) 4/2/94";
#else
-static char rcsid[] = "$OpenBSD: ar.c,v 1.5 1999/12/15 05:33:23 deraadt Exp $";
+static char rcsid[] = "$OpenBSD: ar.c,v 1.6 2000/11/20 14:03:30 deraadt Exp $";
#endif
#endif /* not lint */
@@ -203,7 +203,7 @@ main(argc, argv)
/* -t only valid with -Tv. */
if (options & AR_T && options & ~(AR_T|AR_TR|AR_V))
badoptions("-t");
/* -x only valid with -ouTv. */
if (options & AR_X && options & ~(AR_O|AR_U|AR_TR|AR_V|AR_X|AR_CC))
badoptions("-x");
@@ -242,6 +242,6 @@ usage()
(void)fprintf(stderr, "\tar -r [-cuTv] archive file ...\n");
(void)fprintf(stderr, "\tar -r [-abciuTv] position archive file ...\n");
(void)fprintf(stderr, "\tar -t [-Tv] archive [file ...]\n");
- (void)fprintf(stderr, "\tar -x [-ouTv] archive [file ...]\n");
+ (void)fprintf(stderr, "\tar -x [-CouTv] archive [file ...]\n");
exit(1);
}
@@ -203,7 +203,7 @@ main(argc, argv)
if (options & AR_T && options & ~(AR_T|AR_TR|AR_V))
badoptions("-t");
- /* -x only valid with -ouTv. */
+ /* -x only valid with -CouTv. */
if (options & AR_X && options & ~(AR_O|AR_U|AR_TR|AR_V|AR_X|AR_CC))
badoptions("-x");